@@ -139,7 +139,7 @@ from dataclasses import dataclass, field
 from typing import Callable, MutableMapping, Sized, Union, Optional, Iterable, Any
 
 from i2.signatures import (
-    call_forgivingly,
+    call_somewhat_forgivingly,
     Parameter,
     empty,
     Sig,
@@ -271,21 +271,11 @@ def hook_up(func, variables: MutableMapping, output_name=None):
         output_key = _func.__name__
 
     def source_from_decorated():
-        variables[output_key] = call_forgivingly(_func, **variables)
+        variables[output_key] = call_somewhat_forgivingly(_func, (), variables)
 
     return source_from_decorated
 
 
-# replaced by call_forgivingly
-# def call_func_ignoring_excess(func, **kwargs):
-#     """Call func, sourcing the arguments from kwargs and ignoring the excess arguments.
-#     Also works if func has some position only arguments.
-#     """
-#     s = Sig(func)
-#     args, kwargs = s.args_and_kwargs_from_kwargs(s.source_kwargs(**kwargs))
-#     return func(*args, **kwargs)
-
-
 def _complete_dict_with_iterable_of_required_keys(
     to_complete: dict, complete_with: Iterable
 ):
@@ -792,6 +782,8 @@ class DAG:
         def ensure_variable_list(obj):
             if obj is None:
                 return self.var_nodes
+            if isinstance(obj, str):
+                obj = obj.split()
             if isinstance(obj, (str, Callable)):
                 return [self.get_node_matching(obj)]
             elif isinstance(obj, Iterable):
